@@ -1,6 +1,6 @@
-{-# LANGUAGE DeriveDataTypeable #-}
 {-# LANGUAGE ForeignFunctionInterface #-}
 {-# LANGUAGE OverloadedStrings #-}
+{-# OPTIONS_GHC -fno-warn-deprecations #-} -- Pattern match 'PersistDbSpecific'
 -- | A port of the direct-sqlite package for dealing directly with
 -- 'PersistValue's.
 module Database.Sqlite  (
@@ -52,6 +52,7 @@ module Database.Sqlite  (
     -- > $ ([PersistInt64 1,PersistInt64 1],[PersistInt64 2,PersistInt64 2])
 
                          open,
+                         open',
                          close,
                          prepare,
                          step,
@@ -92,12 +93,11 @@ import Data.Text (Text, pack, unpack)
 import Data.Text.Encoding (encodeUtf8, decodeUtf8With)
 import Data.Text.Encoding.Error (lenientDecode)
 import Data.Time (defaultTimeLocale, formatTime, UTCTime)
-import Data.Typeable (Typeable)
 import Database.Sqlite.Internal (Connection(..), Connection'(..), Statement(..))
 import Foreign
 import Foreign.C
 
-import Database.Persist (PersistValue (..), listToJSON, mapToJSON)
+import Database.Persist (PersistValue (..), listToJSON, mapToJSON, LiteralType(..))
 
 -- | A custom exception type to make it easier to catch exceptions.
 --
@@ -107,7 +107,7 @@ data SqliteException = SqliteException
     , seFunctionName :: !Text
     , seDetails      :: !Text
     }
-    deriving (Typeable)
+
 instance Show SqliteException where
     show (SqliteException error functionName details) = unpack $ Data.Monoid.mconcat
         ["SQLite3 returned "
@@ -222,10 +222,10 @@ sqlError maybeConnection functionName error = do
 foreign import ccall "sqlite3_open_v2"
   openC :: CString -> Ptr (Ptr ()) -> Int -> CString -> IO Int
 
-openError :: Text -> IO (Either Connection Error)
+openError :: BS.ByteString -> IO (Either Connection Error)
 openError path' = do
     let flag = sqliteFlagReadWrite .|. sqliteFlagCreate .|. sqliteFlagUri
-    BS.useAsCString (encodeUtf8 path') $ \path -> alloca $ \database -> do
+    BS.useAsCString path' $ \path -> alloca $ \database -> do
         err <- decodeError <$> openC path database flag nullPtr
         case err of
             ErrorOK -> do database' <- peek database
@@ -239,7 +239,13 @@ openError path' = do
     sqliteFlagUri       = 0x40
 
 open :: Text -> IO Connection
-open path = do
+open path = open' (encodeUtf8 path)
+
+-- |  Like 'open', but accepts a 'ByteString' instead of a 'Text'.
+--
+-- @since 2.13.3.0
+open' :: BS.ByteString -> IO Connection
+open' path = do
   databaseOrError <- openError path
   case databaseOrError of
     Left database -> return database
@@ -469,9 +475,13 @@ bind statement sqlData = do
             PersistUTCTime d -> bindText statement parameterIndex $ pack $ format8601 d
             PersistList l -> bindText statement parameterIndex $ listToJSON l
             PersistMap m -> bindText statement parameterIndex $ mapToJSON m
-            PersistDbSpecific s -> bindText statement parameterIndex $ decodeUtf8With lenientDecode s
             PersistArray a -> bindText statement parameterIndex $ listToJSON a -- copy of PersistList's definition
             PersistObjectId _ -> P.error "Refusing to serialize a PersistObjectId to a SQLite value"
+
+            -- I know one of these is broken, but the docs for `sqlite3_bind_text` aren't very illuminating.
+            PersistLiteral_ DbSpecific s -> bindText statement parameterIndex $ decodeUtf8With lenientDecode s
+            PersistLiteral_ Unescaped l -> bindText statement parameterIndex $ decodeUtf8With lenientDecode l
+            PersistLiteral_ Escaped e -> bindText statement parameterIndex $ decodeUtf8With lenientDecode e
             )
        $ zip [1..] sqlData
   return ()
